#!/bin/bash

## Script to delete Ranger Groups from database
## Usage: deleteUser.sh -f input.txt -u ranger_user -p password -db ranger 
##    -f       contains newline separated list of groups to be deleted
##    -u       db user name
##    -p       db user password
##    -db      db name


usage() {
  [ "$*" ] && echo "$0: $*"
  sed -n '/^##/,/^$/s/^## \{0,1\}//p' "$0"
  exit 2
} 2>/dev/null


while [ "$1" != "" ]; do
    case $1 in
        -f | --file )           shift
                                filename=$1
                                ;;
        -u | --username )		shift
								user=$1
                                ;;
        -p | --password )		shift
								passwd=$1
                                ;;
        -db | --db )            shift
								dbname=$1
								;;
        -h | --help )           usage
                                exit
                                ;;
        * )                     usage
                                exit 1
    esac
    shift
done

if [ -z "$filename" ];	then	usage; exit 1; fi 
if [ -z "$user" ];		then	usage; exit 1; fi 
if [ -z "$passwd" ];	then	usage; exit 1; fi 
if [ -z "$dbname" ];	then	usage; exit 1; fi 

mysqlex="mysql -u${user} -p${passwd} $dbname"

$mysqlex  <<EOF
DELIMITER $$
CREATE PROCEDURE deleteGroupByGroupName(grpName varchar(1024))
BEGIN
declare grpId bigint;
set grpId = (select id from x_group where group_name=grpName);
if(grpId is not null) then
	delete from x_audit_map where group_id = grpId;
	delete from x_group_users where p_group_id = grpId;
	delete from x_perm_map where group_id = grpId;
	delete from x_group_groups where group_id = grpId or p_group_id = grpId;
	delete from x_group where id = grpId;
end if;
END
EOF

while read line
do
    name=$(echo $line)
	if [ -z "$name" ]; then	continue; fi
		name=$(echo "$name" | sed "s|\\\0|\\\\\\0|g")
		name=$(echo "$name" | sed "s|'|\\\'|g")
		name=$(echo "$name" | sed "s|%|\\\%|g")
		name=$(echo "$name" | sed "s|\\\_|\\\\\\\_|g")
		name=$(echo "$name" | sed "s|Z|\\\Z|g")
    echo "  Deleting group : $name"
	$mysqlex -e "CALL deleteGroupByGroupName(\"$name\")"
done < $filename

$mysqlex -e "DROP PROCEDURE IF EXISTS deleteGroupByGroupName"

echo "Deleted all Groups successfully"


